# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-namespace-clean
Summary:	Keep your namespace tidy
Version:	0.27
Release:	23.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/namespace-clean
Source0:	https://cpan.metacpan.org/authors/id/R/RI/RIBASUSHI/namespace-clean-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.14.0
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
# Module Runtime
BuildRequires:	perl(B::Hooks::EndOfScope) >= 0.12
BuildRequires:	perl(base)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Package::Stash) >= 0.23
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(DB)
BuildRequires:	perl(File::Glob)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(IPC::Open2)
BuildRequires:	perl(lib)
BuildRequires:	perl(sort)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Variable::Magic)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(B::Hooks::EndOfScope) >= 0.12
Requires:	perl(Package::Stash) >= 0.23

# namespace::clean::_Util is a private package
%global __requires_exclude ^perl\\(namespace::clean::_Util\\)

%description
When you define a function, or import one, into a Perl package, it will
naturally also be available as a method. This does not per se cause
problems, but it can complicate subclassing and, for example, plugin
classes that are included via multiple inheritance by loading them as
base classes.

The 'namespace::clean' pragma will remove all previously declared or
imported symbols at the end of the current package's compile cycle.
Functions called in the package itself will still be bound by their
name, but they won't show up as methods on your class or instances.

%prep
%setup -q -n namespace-clean-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes
%{perl_vendorlib}/namespace/
%{_mandir}/man3/namespace::clean.3*

%changelog
* Wed May  3 2023 Paul Howarth <paul@city-fan.org> - 0.27-23
- Use SPDX-format license tag
- Drop support for building with perl < 5.14
- Drop support for building with rpm < 4.9

* Fri Jun  7 2019 Paul Howarth <paul@city-fan.org> - 0.27-11
- Perl 5.30 rebuild

* Wed Apr 25 2018 Paul Howarth <paul@city-fan.org> - 0.27-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Jul 30 2016 Paul Howarth <paul@city-fan.org> - 0.27-2
- Fix FTBFS when perl is not in the minimal buildroot

* Thu May 19 2016 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Allow packages to be cleaned multiple times
  - Ensure the debugger workarounds are applied only when DB::sub is actively
    used (they are superfluous otherwise)
  - Work around P5#72210, resulting in fails on 5.8.8 -Duselongdouble
  - Fix incorrect name in META (CPAN RT#107813)
- BR: perl-generators where available
- Simplify find command using -delete
- Drop upstreamed patch for building with Test::More < 0.88

* Wed Oct  7 2015 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - Exclusively use Package::Stash::PP on perls < 5.8.7 until a fixed
    Package::Stash::XS ships - breakage keeps getting re-introduced
    (CPAN RT#74151, CPAN RT#107343)
  - Explicitly document the late runtime binding of 'sort SUBNAME ...'
    (CPAN RT#101247)
  - No longer rely on Sub::Identify - either use Sub::Util or B (CPAN RT#96945)
- Classify buildreqs by usage
- Update patch for building with old Test::More versions
- Filter dependency on private package namespace::clean::_Util

* Sun Sep 14 2014 Paul Howarth <paul@city-fan.org> - 0.25-3
- Drop %%defattr, redundant since rpm 4.4

* Wed Mar  5 2014 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Fix incorrect ExtUtils::CBuilder detection routine leading to Makefile.PL
    crashes when EU::CB is not available
- Update patch for building with old Test::More versions

* Wed Dec  5 2012 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Properly skip debugger test when optional deps not available
  - Make sure pure-perl tests pass correctly on space-containing paths
    (CPAN RT#77528)
  - Remove all the pure-perl fallback code and depend on PP-capable
    B::H::EOS 0.12
- Module no longer attempts to use Hash::Util::FieldHash, so drop filters
- BR: perl(Sub::Identify) and perl(Sub::Name) unconditionally
- BR: perl(ExtUtils::CBuilder)
- Update patch for building with old Test::More versions

* Fri Jul 13 2012 Paul Howarth <paul@city-fan.org> - 0.23-2
- BR: perl(base) and perl(lib)
- Drop BR: perl(FindBin) - not dual-lived

* Sun Mar 11 2012 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Rely on B::Hooks::EndOfScope version 0.10 to fix issues with new
    Module::Runtime versions (≥ 0.012) on perl 5.10 due to incorrect hook
    firing due to %^H localisation
  - Fix failures on 5.13.6 due to incorrect version number threshold
    (CPAN RT#74683)
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}

* Fri Jan 27 2012 Paul Howarth <paul@city-fan.org> - 0.22-2
- Add runtime dependency on perl(B::Hooks::EndOfScope) ≥ 0.07
- Only BR:/R: Sub::Identify and Sub::Name for perl versions where they're
  actually needed

* Tue Dec 27 2011 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Limit the debugger workarounds to perls between 5.8.8 and 5.14, extend
    debugger support to all perl versions (CPAN RT#69862)
  - If possible, automatically install (but not load) the debugger workaround
    libraries on perls between 5.8.8 and 5.14 (CPAN RT#72368)
  - Add back dropped NAME section (CPAN RT#70259)
  - Simplify the ≥ 5.10 PP variant even more - move the hook from DESTROY
    into DELETE
  - Force explicit callback invocation order on 5.8 PP
  - Replace the %^H tie approach with fieldhashes, which fixes all known
    corner cases and caveats on supported perls ≥ 5.8.1 (CPAN RT#73402)
  - compile away the debugger fixup on perls ≥ 5.15.5
- No author tests to run now
- Update patch for building with old Test::More versions
- Filter dependency on Hash::Util::FieldHash on perl 5.8.x

* Thu Aug  4 2011 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Only invoke the deleted sub stashing if we run under a debugger (avoid
    runtime penalty of Sub::Name/Sub::Identify)
  - Spelling fixes (CPAN RT#54388)
  - When B::Hooks::EndOfScope is not available, switch to a simple tie() of %^H
  - Document how to disable the tie() fallback
- This release by RIBASUSHI -> update source URL
- No README file in upstream tarball
- Run the author test if we have perl < 5.14.0 (CPAN RT#69862)
- Patch for old ExtUtils::MakeMaker versions no longer needed
- Update patch for old Test::More versions
- BR: perl(Devel::Hide) for pure perl test
- Bump perl(Package::Stash) version requirement to 0.23
- Drop no-longer-needed build requirements: perl(Pod::Coverage::TrustPod),
  perl(Test::EOL), perl(Test::NoTabs), perl(Test::Pod) and
  perl(Test::Pod::Coverage)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 0.20-3
- Rebuild for perl 5.14.1 in Rawhide
- Skip author test as it fails with perl 5.14.1
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Apr 29 2011 Paul Howarth <paul@city-fan.org> - 0.20-2
- Import from Fedora

* Sat Jan 08 2011 Iain Arnell <iarnell@gmail.com> - 0.20-1
- Update to latest upstream version
- Update BR perl(Package::Stash) >= 0.22

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.18-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 01 2010 Iain Arnell <iarnell@gmail.com> - 0.18-1
- Update by Fedora::App::MaintainerTools 0.006
- Updating to latest GA CPAN version (0.18)
- Added a new br on perl(Exporter) (version 0)
- Altered br on perl(ExtUtils::MakeMaker) (6.42 => 6.31)
- Added a new br on perl(Package::Stash) (version 0.03)
- Added a new br on perl(constant) (version 0)
- Added a new br on perl(vars) (version 0)
- Dropped old BR on perl(Symbol)
- Dropped old requires on perl(Symbol)
- Manually drop unnecessary requires

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.14-1
- Mass rebuild with perl-5.12.0 & update

* Tue Feb 23 2010 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-2
- Update by Fedora::App::MaintainerTools 0.003
- PERL_INSTALL_ROOT => DESTDIR

* Fri Feb 05 2010 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-1
- Update filtering perl_default_filter
- Auto-update to 0.13 (by cpan-spec-update 0.01)
- Altered br on perl(ExtUtils::MakeMaker) (0 => 6.42)
- Added a new br on perl(Sub::Identify) (version 0.04)
- Added a new br on perl(Sub::Name) (version 0.04)
- Altered br on perl(Test::More) (0.62 => 0.88)
- Added a new br on CPAN (inc::Module::AutoInstall found)
- Added a new req on perl(B::Hooks::EndOfScope) (version 0.07)
- Added a new req on perl(Sub::Identify) (version 0.04)
- Added a new req on perl(Sub::Name) (version 0.04)
- Added a new req on perl(Symbol) (version 0)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.11-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Apr 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.11-1
- Update to 0.11

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.09-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 02 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.09-1
- Update to 0.09
- Note BR change from Scope::Guard to B::Hooks::EndOfScope

* Mon Sep 08 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.08-2
- Bump

* Sat Sep 06 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.08-1
- Initial Fedora packaging
- Generated with cpan2dist (CPANPLUS::Dist::Fedora version 0.0.1)
